From 4d1065f8e7d5d65cfa47bf7f8b2d14308a0f564b Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?=C5=81ukasz=20Nowak?= <luke@nexedi.com>
Date: Wed, 28 Dec 2011 14:13:33 +0100
Subject: [PATCH] Typo.

---
 .../Vifib/tests/testVifibInstanceHostingRelatedDocument.py    | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/master/product/Vifib/tests/testVifibInstanceHostingRelatedDocument.py b/master/product/Vifib/tests/testVifibInstanceHostingRelatedDocument.py
index 3eb20f81a..3ae693f49 100644
--- a/master/product/Vifib/tests/testVifibInstanceHostingRelatedDocument.py
+++ b/master/product/Vifib/tests/testVifibInstanceHostingRelatedDocument.py
@@ -455,11 +455,11 @@ class TestVifibInstanceHostingRelatedDocument(TestVifibSlapWebServiceMixin):
 
     # there shall be one payment transaction related to started invoice
     payment_transaction_list = started_invoice.getCausalityRelatedValueList(
-      portal_type='Payment Transcation')
+      portal_type='Payment Transaction')
     self.assertEqual(1, len(payment_transaction_list))
     payment_transaction = payment_transaction_list[0]
 
     # this payment transcation shall be planned and solved
     self.assertEqual('planned', payment_transaction.getSimulationState())
     self.assertEqual('solved', payment_transaction.getCausalityState())
 
@@ -455,11 +455,11 @@ class TestVifibInstanceHostingRelatedDocument(TestVifibSlapWebServiceMixin):
     payment_transaction = payment_transaction_list[0]
 
-    # this payment transcation shall be planned and solved
+    # this payment transaction shall be planned and solved
     self.assertEqual('planned', payment_transaction.getSimulationState())
     self.assertEqual('solved', payment_transaction.getCausalityState())
-- 
2.30.9